# coding: utf-8
import subprocess
from logging import getLogger

from .. import AbstractOSIntegration

__all__ = ("LinuxIntegration",)

log = getLogger(__name__)


class LinuxIntegration(AbstractOSIntegration):

    nature = "GNU/Linux"

    @staticmethod
    def cb_get() -> str:
        """Get the text data from the clipboard. The xclip tool needs to be installed.
        Emulate: xclip -selection c -o
        """
        data = subprocess.check_output(["xclip", "-selection", "c", "-o"])
        return data.decode("utf-8")

    @staticmethod
    def cb_set(text: str) -> None:
        """Copy some *text* into the clipboard. The xclip tool needs to be installed.
        Emulate: echo "blablabla" | xclip -selection c
        """
        with subprocess.Popen(["xclip", "-selection", "c"], stdin=subprocess.PIPE) as p:
            p.stdin.write(text.encode("utf-8"))
            p.stdin.close()
            p.wait()

    def open_local_file(self, file_path: str, select: bool = False) -> None:
        """Note that this function must _not_ block the execution."""
        if select:
            log.info(
                "The Select/Highlight feature is not yet implemented, please vote "
                "https://jira.nuxeo.com/browse/NXDRIVE-848 to show your interest"
            )

        # xdg-open should be supported by recent Gnome, KDE, Xfce
        subprocess.Popen(["xdg-open", file_path])
